The serverity level should correspond to the condition class.
build.log.entry(timestamp, severity, msg.text, call.stack, dump.file.name,
omit.call.stack.items = 0)severity level of the log entry ((ERROR, WARN, INFO etc.)
Logging message (e. g. error message)
a call stack created by sys.calls
name of the created dump file (leave empty if the tryCatchLog
argument write.error.dump.file is FALSE
the number of stack trace items to ignore (= last x calls) in
the passed call.stack since they are caused by using tryCatchLog
An object of class tryCatchLog.log.entry and data.frame with one and the following columns:
timestamp - creation date and time of the logging entry
severity - the serverity level of the log entry (ERROR, WARN, INFO etc.)
msg.text - the message text of the log entry
compact.stack.trace - the short stack trace containing only entries with source code references down to line of code that has thrown the condition
full.stack.trace - the full stack trace with all calls down to the line of code that has thrown the condition (including calls to R internal functions and other functions even when the source code in not available).
dump.file.name - name of the created dump file (if any)